import { Hono } from 'hono';
import { PostPage } from '@blog/templates/Pages/PostPage';
import { FourOhFour } from '@blog/templates/Pages/FourOhFour';
import { readdir } from 'node:fs/promises';
import { SiteMeta } from '@blog/model/SiteMeta';
import { readPostMarkdown } from '@blog/post/post-reader';

const app = new Hono();

app.get('/:slug', async (c) => {
  const postSlug: string = c.req.param("slug");
  const fileName: string = postSlug + '.md';
  const files = await readdir(__dirname + "/../../posts");

  const postFile = files.find(f => f === fileName);
  if (!postFile) {
    c.status(404);
    const meta: SiteMeta = {
      description: "Page does not exist."
    };
    return c.render(<FourOhFour />, { meta });
  }

  const post = await readPostMarkdown(__dirname + "/../../posts/" + postFile);
  const meta: SiteMeta = {
    description: post.meta.description,
    tags: post.meta.tags,
    author: "Dave Smith-Hayes"
  };

  return c.render(<PostPage post={post} />, { meta });
});

export default app;

